[FFmpeg-cvslog] drop LLS1, rename LLS2 to LLS

Michael Niedermayer git at videolan.org
Sun Aug 10 00:49:11 CEST 2014


ffmpeg | branch: master | Michael Niedermayer <michaelni at gmx.at> | Sat Aug  9 23:03:26 2014 +0200| [70b8668fb532a7efd2953822872285d1e9947375] | committer: Michael Niedermayer

drop LLS1, rename LLS2 to LLS

Signed-off-by: Michael Niedermayer <michaelni at gmx.at>

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=70b8668fb532a7efd2953822872285d1e9947375
---

 libavcodec/lpc.c            |    8 +-
 libavutil/Makefile          |    6 +-
 libavutil/{lls2.c => lls.c} |   18 ++---
 libavutil/{lls2.h => lls.h} |   16 ++--
 libavutil/lls1.c            |  180 -------------------------------------------
 libavutil/lls1.h            |   54 -------------
 libavutil/x86/lls.asm       |    8 +-
 libavutil/x86/lls_init.c    |   10 +--
 8 files changed, 32 insertions(+), 268 deletions(-)

diff --git a/libavcodec/lpc.c b/libavcodec/lpc.c
index a6f2377..1d52edf 100644
--- a/libavcodec/lpc.c
+++ b/libavcodec/lpc.c
@@ -20,7 +20,7 @@
  */
 
 #include "libavutil/common.h"
-#include "libavutil/lls2.h"
+#include "libavutil/lls.h"
 
 #define LPC_USE_DOUBLE
 #include "lpc.h"
@@ -208,7 +208,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
     }
 
     if (lpc_type == FF_LPC_TYPE_CHOLESKY) {
-        LLSModel2 m[2];
+        LLSModel m[2];
         LOCAL_ALIGNED(32, double, var, [FFALIGN(MAX_LPC_ORDER+1,4)]);
         double av_uninit(weight);
         memset(var, 0, FFALIGN(MAX_LPC_ORDER+1,4)*sizeof(*var));
@@ -217,7 +217,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
             m[0].coeff[max_order-1][j] = -lpc[max_order-1][j];
 
         for(; pass<lpc_passes; pass++){
-            avpriv_init_lls2(&m[pass&1], max_order);
+            avpriv_init_lls(&m[pass&1], max_order);
 
             weight=0;
             for(i=max_order; i<blocksize; i++){
@@ -238,7 +238,7 @@ int ff_lpc_calc_coefs(LPCContext *s,
 
                 m[pass&1].update_lls(&m[pass&1], var);
             }
-            avpriv_solve_lls2(&m[pass&1], 0.001, 0);
+            avpriv_solve_lls(&m[pass&1], 0.001, 0);
         }
 
         for(i=0; i<max_order; i++){
diff --git a/libavutil/Makefile b/libavutil/Makefile
index d57a741..d3a9245 100644
--- a/libavutil/Makefile
+++ b/libavutil/Makefile
@@ -102,8 +102,7 @@ OBJS = adler32.o                                                        \
        intfloat_readwrite.o                                             \
        intmath.o                                                        \
        lfg.o                                                            \
-       lls1.o                                                           \
-       lls2.o                                                           \
+       lls.o                                                            \
        log.o                                                            \
        log2_tab.o                                                       \
        mathematics.o                                                    \
@@ -163,8 +162,7 @@ TESTPROGS = adler32                                                     \
             float_dsp                                                   \
             hmac                                                        \
             lfg                                                         \
-            lls1                                                        \
-            lls2                                                        \
+            lls                                                         \
             log                                                         \
             md5                                                         \
             murmur3                                                     \
diff --git a/libavutil/lls2.c b/libavutil/lls.c
similarity index 90%
rename from libavutil/lls2.c
rename to libavutil/lls.c
index 8cadacb..06fe423 100644
--- a/libavutil/lls2.c
+++ b/libavutil/lls.c
@@ -30,9 +30,9 @@
 
 #include "attributes.h"
 #include "version.h"
-#include "lls2.h"
+#include "lls.h"
 
-static void update_lls(LLSModel2 *m, double *var)
+static void update_lls(LLSModel *m, double *var)
 {
     int i, j;
 
@@ -43,7 +43,7 @@ static void update_lls(LLSModel2 *m, double *var)
     }
 }
 
-void avpriv_solve_lls2(LLSModel2 *m, double threshold, unsigned short min_order)
+void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order)
 {
     int i, j, k;
     double (*factor)[MAX_VARS_ALIGN] = (void *) &m->covariance[1][0];
@@ -100,7 +100,7 @@ void avpriv_solve_lls2(LLSModel2 *m, double threshold, unsigned short min_order)
     }
 }
 
-static double evaluate_lls(LLSModel2 *m, double *param, int order)
+static double evaluate_lls(LLSModel *m, double *param, int order)
 {
     int i;
     double out = 0;
@@ -111,9 +111,9 @@ static double evaluate_lls(LLSModel2 *m, double *param, int order)
     return out;
 }
 
-av_cold void avpriv_init_lls2(LLSModel2 *m, int indep_count)
+av_cold void avpriv_init_lls(LLSModel *m, int indep_count)
 {
-    memset(m, 0, sizeof(LLSModel2));
+    memset(m, 0, sizeof(LLSModel));
     m->indep_count = indep_count;
     m->update_lls = update_lls;
     m->evaluate_lls = evaluate_lls;
@@ -129,12 +129,12 @@ av_cold void avpriv_init_lls2(LLSModel2 *m, int indep_count)
 
 int main(void)
 {
-    LLSModel2 m;
+    LLSModel m;
     int i, order;
     AVLFG lfg;
 
     av_lfg_init(&lfg, 1);
-    avpriv_init_lls2(&m, 3);
+    avpriv_init_lls(&m, 3);
 
     for (i = 0; i < 100; i++) {
         LOCAL_ALIGNED(32, double, var, [4]);
@@ -145,7 +145,7 @@ int main(void)
         var[2] = var[1] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
         var[3] = var[2] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
         m.update_lls(&m, var);
-        avpriv_solve_lls2(&m, 0.001, 0);
+        avpriv_solve_lls(&m, 0.001, 0);
         for (order = 0; order < 3; order++) {
             eval = m.evaluate_lls(&m, var + 1, order);
             printf("real:%9f order:%d pred:%9f var:%f coeffs:%f %9f %9f\n",
diff --git a/libavutil/lls1.c b/libavutil/lls1.c
deleted file mode 100644
index c452d82..0000000
--- a/libavutil/lls1.c
+++ /dev/null
@@ -1,180 +0,0 @@
-/*
- * linear least squares model
- *
- * Copyright (c) 2006 Michael Niedermayer <michaelni at gmx.at>
- *
- * This file is part of FFmpeg.
- *
- * FFmpeg is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * FFmpeg is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with FFmpeg; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-/**
- * @file
- * linear least squares model
- */
-
-#include <math.h>
-#include <string.h>
-
-#include "attributes.h"
-#include "version.h"
-#include "lls1.h"
-
-#if FF_API_LLS1
-
-av_cold void avpriv_init_lls(LLSModel *m, int indep_count)
-{
-    memset(m, 0, sizeof(LLSModel));
-    m->indep_count = indep_count;
-}
-
-void avpriv_update_lls(LLSModel *m, double *var, double decay)
-{
-    int i, j;
-
-    for (i = 0; i <= m->indep_count; i++) {
-        for (j = i; j <= m->indep_count; j++) {
-            m->covariance[i][j] *= decay;
-            m->covariance[i][j] += var[i] * var[j];
-        }
-    }
-}
-
-void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order)
-{
-    int i, j, k;
-    double (*factor)[MAX_VARS + 1] = (void *) &m->covariance[1][0];
-    double (*covar) [MAX_VARS + 1] = (void *) &m->covariance[1][1];
-    double *covar_y                = m->covariance[0];
-    int count                      = m->indep_count;
-
-    for (i = 0; i < count; i++) {
-        for (j = i; j < count; j++) {
-            double sum = covar[i][j];
-
-            for (k = i - 1; k >= 0; k--)
-                sum -= factor[i][k] * factor[j][k];
-
-            if (i == j) {
-                if (sum < threshold)
-                    sum = 1.0;
-                factor[i][i] = sqrt(sum);
-            } else {
-                factor[j][i] = sum / factor[i][i];
-            }
-        }
-    }
-
-    for (i = 0; i < count; i++) {
-        double sum = covar_y[i + 1];
-
-        for (k = i - 1; k >= 0; k--)
-            sum -= factor[i][k] * m->coeff[0][k];
-
-        m->coeff[0][i] = sum / factor[i][i];
-    }
-
-    for (j = count - 1; j >= min_order; j--) {
-        for (i = j; i >= 0; i--) {
-            double sum = m->coeff[0][i];
-
-            for (k = i + 1; k <= j; k++)
-                sum -= factor[k][i] * m->coeff[j][k];
-
-            m->coeff[j][i] = sum / factor[i][i];
-        }
-
-        m->variance[j] = covar_y[0];
-
-        for (i = 0; i <= j; i++) {
-            double sum = m->coeff[j][i] * covar[i][i] - 2 * covar_y[i + 1];
-
-            for (k = 0; k < i; k++)
-                sum += 2 * m->coeff[j][k] * covar[k][i];
-
-            m->variance[j] += m->coeff[j][i] * sum;
-        }
-    }
-}
-
-double avpriv_evaluate_lls(LLSModel *m, double *param, int order)
-{
-    int i;
-    double out = 0;
-
-    for (i = 0; i <= order; i++)
-        out += param[i] * m->coeff[order][i];
-
-    return out;
-}
-
-#if FF_API_LLS_PRIVATE
-av_cold void av_init_lls(LLSModel *m, int indep_count)
-{
-    avpriv_init_lls(m, indep_count);
-}
-void av_update_lls(LLSModel *m, double *param, double decay)
-{
-    avpriv_update_lls(m, param, decay);
-}
-void av_solve_lls(LLSModel *m, double threshold, int min_order)
-{
-    avpriv_solve_lls(m, threshold, min_order);
-}
-double av_evaluate_lls(LLSModel *m, double *param, int order)
-{
-    return avpriv_evaluate_lls(m, param, order);
-}
-#endif /* FF_API_LLS_PRIVATE */
-
-#endif /* FF_API_LLS1 */
-
-#ifdef TEST
-
-#include <stdio.h>
-#include <limits.h>
-#include "lfg.h"
-
-int main(void)
-{
-    LLSModel m;
-    int i, order;
-    AVLFG lfg;
-
-    av_lfg_init(&lfg, 1);
-    avpriv_init_lls(&m, 3);
-
-    for (i = 0; i < 100; i++) {
-        double var[4];
-        double eval;
-
-        var[0] = (av_lfg_get(&lfg) / (double) UINT_MAX - 0.5) * 2;
-        var[1] = var[0] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
-        var[2] = var[1] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
-        var[3] = var[2] + av_lfg_get(&lfg) / (double) UINT_MAX - 0.5;
-        avpriv_update_lls(&m, var, 0.99);
-        avpriv_solve_lls(&m, 0.001, 0);
-        for (order = 0; order < 3; order++) {
-            eval = avpriv_evaluate_lls(&m, var + 1, order);
-            printf("real:%9f order:%d pred:%9f var:%f coeffs:%f %9f %9f\n",
-                   var[0], order, eval, sqrt(m.variance[order] / (i + 1)),
-                   m.coeff[order][0], m.coeff[order][1],
-                   m.coeff[order][2]);
-        }
-    }
-    return 0;
-}
-
-#endif
diff --git a/libavutil/lls1.h b/libavutil/lls1.h
deleted file mode 100644
index c785d44..0000000
--- a/libavutil/lls1.h
+++ /dev/null
@@ -1,54 +0,0 @@
-/*
- * linear least squares model
- *
- * Copyright (c) 2006 Michael Niedermayer <michaelni at gmx.at>
- *
- * This file is part of FFmpeg.
- *
- * FFmpeg is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * FFmpeg is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with FFmpeg; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-#ifndef AVUTIL_LLS_H
-#define AVUTIL_LLS_H
-
-#include "version.h"
-
-#define MAX_VARS 32
-
-//FIXME avoid direct access to LLSModel from outside
-
-/**
- * Linear least squares model.
- */
-typedef struct LLSModel {
-    double covariance[MAX_VARS + 1][MAX_VARS + 1];
-    double coeff[MAX_VARS][MAX_VARS];
-    double variance[MAX_VARS];
-    int indep_count;
-} LLSModel;
-
-void avpriv_init_lls(LLSModel *m, int indep_count);
-void avpriv_update_lls(LLSModel *m, double *param, double decay);
-void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order);
-double avpriv_evaluate_lls(LLSModel *m, double *param, int order);
-
-#if FF_API_LLS_PRIVATE
-void av_init_lls(LLSModel *m, int indep_count);
-void av_update_lls(LLSModel *m, double *param, double decay);
-void av_solve_lls(LLSModel *m, double threshold, int min_order);
-double av_evaluate_lls(LLSModel *m, double *param, int order);
-#endif /* FF_API_LLS_PRIVATE */
-
-#endif /* AVUTIL_LLS_H */
diff --git a/libavutil/x86/lls.asm b/libavutil/x86/lls.asm
index c2aead3..769befb 100644
--- a/libavutil/x86/lls.asm
+++ b/libavutil/x86/lls.asm
@@ -29,7 +29,7 @@ SECTION .text
 %define COVAR_STRIDE MAX_VARS_ALIGN*8
 %define COVAR(x,y) [covarq + (x)*8 + (y)*COVAR_STRIDE]
 
-struc LLSModel2
+struc LLSModel
     .covariance:  resq MAX_VARS_ALIGN*MAX_VARS_ALIGN
     .coeff:       resq MAX_VARS*MAX_VARS
     .variance:    resq MAX_VARS
@@ -49,7 +49,7 @@ INIT_XMM sse2
 %define movdqa movaps
 cglobal update_lls, 2,5,8, ctx, var, i, j, covar2
     %define covarq ctxq
-    mov     id, [ctxq + LLSModel2.indep_count]
+    mov     id, [ctxq + LLSModel.indep_count]
     lea   varq, [varq + iq*8]
     neg     iq
     mov covar2q, covarq
@@ -129,7 +129,7 @@ cglobal update_lls, 2,5,8, ctx, var, i, j, covar2
 INIT_YMM avx
 cglobal update_lls, 3,6,8, ctx, var, count, i, j, count2
     %define covarq ctxq
-    mov  countd, [ctxq + LLSModel2.indep_count]
+    mov  countd, [ctxq + LLSModel.indep_count]
     lea count2d, [countq-2]
     xor     id, id
 .loopi:
@@ -206,7 +206,7 @@ cglobal evaluate_lls, 3,4,2, ctx, var, order, i
     %define coefsq ctxq
     mov     id, orderd
     imul    orderd, MAX_VARS
-    lea     coefsq, [ctxq + LLSModel2.coeff + orderq*8]
+    lea     coefsq, [ctxq + LLSModel.coeff + orderq*8]
     movsd   m0, [varq]
     movhpd  m0, [varq + 8]
     mulpd   m0, [coefsq]
diff --git a/libavutil/x86/lls_init.c b/libavutil/x86/lls_init.c
index bf999d5..181ca38 100644
--- a/libavutil/x86/lls_init.c
+++ b/libavutil/x86/lls_init.c
@@ -20,14 +20,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "libavutil/lls2.h"
+#include "libavutil/lls.h"
 #include "libavutil/x86/cpu.h"
 
-void ff_update_lls_sse2(LLSModel2 *m, double *var);
-void ff_update_lls_avx(LLSModel2 *m, double *var);
-double ff_evaluate_lls_sse2(LLSModel2 *m, double *var, int order);
+void ff_update_lls_sse2(LLSModel *m, double *var);
+void ff_update_lls_avx(LLSModel *m, double *var);
+double ff_evaluate_lls_sse2(LLSModel *m, double *var, int order);
 
-av_cold void ff_init_lls_x86(LLSModel2 *m)
+av_cold void ff_init_lls_x86(LLSModel *m)
 {
     int cpu_flags = av_get_cpu_flags();
     if (EXTERNAL_SSE2(cpu_flags)) {



More information about the ffmpeg-cvslog mailing list
diff --git a/libavutil/lls2.h b/libavutil/lls.h
similarity index 82%
rename from libavutil/lls2.h
rename to libavutil/lls.h
index 35815d2..46f9606 100644
--- a/libavutil/lls2.h
+++ b/libavutil/lls.h
@@ -30,12 +30,12 @@
 #define MAX_VARS 32
 #define MAX_VARS_ALIGN FFALIGN(MAX_VARS+1,4)
 
 //FIXME avoid direct access to LLSModel2 from outside
 
 /**
  * Linear least squares model.
  */
-typedef struct LLSModel2 {
+typedef struct LLSModel {
     DECLARE_ALIGNED(32, double, covariance[MAX_VARS_ALIGN][MAX_VARS_ALIGN]);
     DECLARE_ALIGNED(32, double, coeff[MAX_VARS][MAX_VARS]);
     double variance[MAX_VARS];
@@ -47,18 +47,18 @@ typedef struct LLSModel2 {
      *            32-byte aligned, and any padding elements must be initialized
      *            (i.e not denormal/nan).
      */
-    void (*update_lls)(struct LLSModel2 *m, double *var);
+    void (*update_lls)(struct LLSModel *m, double *var);
     /**
      * Inner product of var[] and the LPC coefs.
      * @param m this context
      * @param var training samples, excluding the value to be predicted. unaligned.
      * @param order lpc order
      */
-    double (*evaluate_lls)(struct LLSModel2 *m, double *var, int order);
-} LLSModel2;
+    double (*evaluate_lls)(struct LLSModel *m, double *var, int order);
+} LLSModel;
 
-void avpriv_init_lls2(LLSModel2 *m, int indep_count);
-void ff_init_lls_x86(LLSModel2 *m);
-void avpriv_solve_lls2(LLSModel2 *m, double threshold, unsigned short min_order);
+void avpriv_init_lls(LLSModel *m, int indep_count);
+void ff_init_lls_x86(LLSModel *m);
+void avpriv_solve_lls(LLSModel *m, double threshold, unsigned short min_order);
 
 #endif /* AVUTIL_LLS_H */
@@ -30,12 +30,12 @@
 #define MAX_VARS_ALIGN FFALIGN(MAX_VARS+1,4)
 
-//FIXME avoid direct access to LLSModel2 from outside
+//FIXME avoid direct access to LLSModel from outside
 
 /**